import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixAnalyticsNgV2Data from './analytics-ng-v2-data-analytics-data.http.js';
/** Available measure names */
export var MeasureNameEnum;
(function (MeasureNameEnum) {
    /** Default value. This value is unused. */
    MeasureNameEnum["UNKNOWN_MEASUREMENT_TYPE"] = "UNKNOWN_MEASUREMENT_TYPE";
    /** Total amount of money expected from all product and service sales, before deducting refunds, shipping, and fees, including both online and manual payments. */
    MeasureNameEnum["TOTAL_SALES"] = "TOTAL_SALES";
    /** Total amount of income from sales after deducting refunds. */
    MeasureNameEnum["TOTAL_ORDERS"] = "TOTAL_ORDERS";
    /** Total amount of site sessions where a visitor clicked to contact you via WhatsApp, phone or email. */
    MeasureNameEnum["CLICKS_TO_CONTACT"] = "CLICKS_TO_CONTACT";
    /** Total amount of visitor sessions. */
    MeasureNameEnum["TOTAL_SESSIONS"] = "TOTAL_SESSIONS";
    /** Total amount of forms submitted. */
    MeasureNameEnum["TOTAL_FORMS_SUBMITTED"] = "TOTAL_FORMS_SUBMITTED";
    /** Total amount of unique visitors. */
    MeasureNameEnum["TOTAL_UNIQUE_VISITORS"] = "TOTAL_UNIQUE_VISITORS";
})(MeasureNameEnum || (MeasureNameEnum = {}));
/**
 * Retrieves analytics data, given the specified filtering.
 * @param measurementTypes - Measurement types.
 * @public
 * @requiredField measurementTypes
 * @requiredField options.dateRange
 * @param options - Field options.
 * @permissionId ANALYTICS_AND_REPORTS.ANALYTICS_PUBLIC_READ
 * @permissionScope Site Analytics - read permissions
 * @permissionScopeId SCOPE.DC-ANALYTICS-AND-REPORTS.READ-SITE-ANALYTICS
 * @applicableIdentity APP
 * @returns The response with analytics data
 * @fqn wix.analytics_ng.data.v2.pub.SiteAnalyticsDataService.GetAnalyticsData
 */
export async function getAnalyticsData(measurementTypes, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        measurementTypes: measurementTypes,
        dateRange: options?.dateRange,
        timeZone: options?.timeZone,
    });
    const reqOpts = ambassadorWixAnalyticsNgV2Data.getAnalyticsData(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                measurementTypes: '$[0]',
                dateRange: '$[1].dateRange',
                timeZone: '$[1].timeZone',
            },
            singleArgumentUnchanged: false,
        }, ['measurementTypes', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=analytics-ng-v2-data-analytics-data.universal.js.map